@@ -6,11 +6,8 @@
 <p>
 Mednafen's NES/Famicom emulation is based off of FCE Ultra.
 </p>
-<?php BeginSection('Custom Palettes', "Section_custom_palettes"); ?>
-<p>
-Custom palettes should contain 64 8-bit-per-color-component RGB triplets.
-</p>
-<?php EndSection(); ?>
+
+<?php PrintCustomPalettes(); ?>
 
 <?php BeginSection("Input", "Section_input"); ?>
  <p>
@@ -18,7 +15,7 @@ Custom palettes should contain 64 8-bit-per-color-component RGB triplets.
   adapter, the Zapper, the Power Pad,  and the Arkanoid controller.  The 
   Famicom version of the Arkanoid controller, the "Space Shadow" gun, the 
   Famicom 4-player adapter, the Family Keyboard, the HyperShot controller, the Mahjong controller,
-  the Oeka Kids tablet, the Party Tap, the Family Trainer, and the Barcode World barcode
+  the Oeka Kids tablet, the Party Tap, the Family Trainer, and the Barcode Battler II barcode
   reader are also emulated.
  </p>
 
@@ -98,6 +95,7 @@ Custom palettes should contain 64 8-bit-per-color-component RGB triplets.
  <tr><td>34</td><td>NINA-001 and BNROM</td><td>Impossible Mission 2, Deadly Towers, Bug Honey</td></tr>
  <tr><td>37</td><td>??</td><td>Super Mario Bros/Tetris/Nintendo World Cup</td></tr>
  <tr><td>38</td><td>??</td><td>Crime Busters</td></tr>
+ <tr><td>40</td><td>??</td><td>Super Mario Bros. 2j bootleg</td></tr>
  <tr><td>41</td><td>Caltron 6-in-1</td><td>Caltron 6-in-1</td></tr>
  <tr><td>42</td><td>(bootleg)</td><td>Mario Baby</td></tr>
  <tr><td>44</td><td>Multi-cart(bootleg)</td><td>Super HiK 7 in 1</td></tr>
@@ -170,6 +168,7 @@ Custom palettes should contain 64 8-bit-per-color-component RGB triplets.
  <tr><td>184</td><td>??</td><td>Wing of Madoola, The</td></tr>
  <tr><td>185</td><td>CNROM w/ CHR ROM unmapping</td><td>Banana, Mighty Bomb Jack, Spy vs Spy(Japanese)</td></tr>
  <tr><td>189</td><td>??</td><td>Thunder Warrior, Street Fighter 2 (Yoko)</td></tr>
+ <tr><td>190</td><td>??</td><td>Magic Kid Googoo</td></tr>
  <tr><td>193</td><td>Mega Soft</td><td>Fighting Hero</td></tr>
  <tr><td>206</td><td>DEIROM</td><td>Karnov</td></tr>
  <tr><td>207</td><td>Taito ??</td><td>Fudou Myouou Den</td></tr>
