@@ -1,4 +1,6 @@
-int MDFND_NetworkConnect(void);
+#ifndef __MDFN_DRIVERS_NETPLAY_H
+#define __MDFN_DRIVERS_NETPLAY_H
+
 void NetplayText_InMainThread(uint8 *text, bool NetEcho);
 
 int NetplayEventHook(const SDL_Event *event);
@@ -12,8 +14,15 @@ bool Netplay_TryTextExit(void);
 extern int MDFNDnetplay;
 
 
+//
+//
+//
+void Netplay_GT_CheckPendingLine(void);
+
 //
 //
 //
 
 void Netplay_MT_Draw(const MDFN_PixelFormat& pformat, const int32 screen_w, const int32 screen_h);
+
+#endif
