@@ -109,15 +109,15 @@ struct InputDeviceInputInfoStruct
 	{
          struct
          {
-	  const IDIIS_SwitchPos* SwitchPos;
-	  uint32 SwitchNumPos;
-         };
+	  const IDIIS_SwitchPos* Pos;
+	  uint32 NumPos;
+         } Switch;
 
 	 struct
 	 {
-	  const IDIIS_StatusState* StatusStates;
-	  uint32 StatusNumStates;
-	 };
+	  const IDIIS_StatusState* States;
+	  uint32 NumStates;
+	 } Status;
 	};
 };
 
@@ -157,8 +157,8 @@ struct IDIIS_Switch : public InputDeviceInputInfoStruct
 
 	 ExcludeName = NULL;
 	 Flags = undoc_defpos ? IDIT_FLAG_AUX_SETTINGS_UNDOC : 0;
-	 SwitchPos = spn;
-	 SwitchNumPos = spn_num;
+	 Switch.Pos = spn;
+	 Switch.NumPos = spn_num;
 	}
 };
 
@@ -173,8 +173,8 @@ struct IDIIS_Status : public InputDeviceInputInfoStruct
 
 	 ExcludeName = NULL;
 	 Flags = 0;
-	 StatusStates = ss;
-	 StatusNumStates = ss_num;
+	 Status.States = ss;
+	 Status.NumStates = ss_num;
 	}
 };
 
