@@ -2134,36 +2134,40 @@ void CSusie::StateAction(StateMem *sm, const unsigned load, const bool data_only
 {
  SFORMAT SuzieRegs[] =
  {
-	SFVAR(mTMPADR),
-        SFVAR(mTILTACUM),
-        SFVAR(mHOFF),
-        SFVAR(mVOFF),
-        SFVAR(mVIDBAS),
-        SFVAR(mCOLLBAS),
-        SFVAR(mVIDADR),
-        SFVAR(mCOLLADR),
-        SFVAR(mSCBNEXT),
-        SFVAR(mSPRDLINE),
-        SFVAR(mHPOSSTRT),
-        SFVAR(mVPOSSTRT),
-        SFVAR(mSPRHSIZ),
-        SFVAR(mSPRVSIZ),
-        SFVAR(mSTRETCH),
-        SFVAR(mTILT),
-        SFVAR(mSPRDOFF),
-        SFVAR(mSPRVPOS),
-        SFVAR(mCOLLOFF),
-        SFVAR(mVSIZACUM),
-        SFVAR(mHSIZACUM),
-        SFVAR(mHSIZOFF),
-        SFVAR(mVSIZOFF),
-        SFVAR(mSCBADR),
-        SFVAR(mPROCADR),
+	SFVARN(mTMPADR.Val16, "mTMPADR"),
+        SFVARN(mTILTACUM.Val16, "mTILTACUM"),
+        SFVARN(mHOFF.Val16, "mHOFF"),
+        SFVARN(mVOFF.Val16, "mVOFF"),
+        SFVARN(mVIDBAS.Val16, "mVIDBAS"),
+        SFVARN(mCOLLBAS.Val16, "mCOLLBAS"),
+        SFVARN(mVIDADR.Val16, "mVIDADR"),
+        SFVARN(mCOLLADR.Val16, "mCOLLADR"),
+        SFVARN(mSCBNEXT.Val16, "mSCBNEXT"),
+        SFVARN(mSPRDLINE.Val16, "mSPRDLINE"),
+        SFVARN(mHPOSSTRT.Val16, "mHPOSSTRT"),
+        SFVARN(mVPOSSTRT.Val16, "mVPOSSTRT"),
+        SFVARN(mSPRHSIZ.Val16, "mSPRHSIZ"),
+        SFVARN(mSPRVSIZ.Val16, "mSPRVSIZ"),
+        SFVARN(mSTRETCH.Val16, "mSTRETCH"),
+        SFVARN(mTILT.Val16, "mTILT"),
+        SFVARN(mSPRDOFF.Val16, "mSPRDOFF"),
+        SFVARN(mSPRVPOS.Val16, "mSPRVPOS"),
+        SFVARN(mCOLLOFF.Val16, "mCOLLOFF"),
+        SFVARN(mVSIZACUM.Val16, "mVSIZACUM"),
+        SFVARN(mHSIZACUM.Val16, "mHSIZACUM"),
+        SFVARN(mHSIZOFF.Val16, "mHSIZOFF"),
+        SFVARN(mVSIZOFF.Val16, "mVSIZOFF"),
+        SFVARN(mSCBADR.Val16, "mSCBADR"),
+        SFVARN(mPROCADR.Val16, "mPROCADR"),
 
-        SFVAR(mMATHABCD),
-        SFVAR(mMATHEFGH),
-        SFVAR(mMATHJKLM),
-        SFVAR(mMATHNP),
+        SFVARN(mMATHABCD.Long, "mMATHABCD"),
+        SFVARN(mMATHEFGH.Long, "mMATHEFGH"),
+        SFVARN(mMATHJKLM.Long, "mMATHJKLM"),
+        SFVARN(mMATHNP.Long, "mMATHNP"),
+
+	SFVAR(mMATHAB_sign),
+	SFVAR(mMATHCD_sign),
+	SFVAR(mMATHEFGH_sign),
 
         SFVAR(mSPRCTL0_Type),
         SFVAR(mSPRCTL0_Vflip),
@@ -2194,7 +2198,7 @@ void CSusie::StateAction(StateMem *sm, const unsigned load, const bool data_only
 
         SFVAR(mSUZYBUSEN),
 
-        SFVAR(mSPRINIT),
+        SFVARN(mSPRINIT.Byte, "mSPRINIT"),
         SFVAR(mSPRGO),
         SFVAR(mEVERON),
 
@@ -2212,8 +2216,8 @@ void CSusie::StateAction(StateMem *sm, const unsigned load, const bool data_only
         SFVAR(mLineBaseAddress),
         SFVAR(mLineCollisionAddress),
 
-        SFVAR(mJOYSTICK),
-        SFVAR(mSWITCHES),
+        SFVARN(mJOYSTICK.Byte, "mJOYSTICK"),
+        SFVARN(mSWITCHES.Byte, "mSWITCHES"),
 	SFVAR(hquadoff),
 	SFVAR(vquadoff),
 	SFEND
