@@ -3,7 +3,6 @@
 
 #include "mempatcher-driver.h"
 #include "Stream.h"
-#include <vector>
 
 // Substitution cheat/patch stuff
 struct SUBCHEAT
@@ -17,10 +16,10 @@ extern std::vector<SUBCHEAT> SubCheats[8];
 extern bool SubCheatsOn;
 
 
-void MDFNMP_Init(uint32 ps, uint32 numpages);
+void MDFNMP_Init(uint32 ps, uint32 numpages) MDFN_COLD;
 void MDFNMP_AddRAM(uint32 size, uint32 address, uint8 *RAM, bool use_in_search = true);	// Deprecated
 void MDFNMP_RegSearchable(uint32 addr, uint32 size);
-void MDFNMP_Kill(void);
+void MDFNMP_Kill(void) MDFN_COLD;
 
 void MDFN_LoadGameCheats(Stream* override = NULL);
 void MDFNMP_InstallReadPatches(void);
@@ -28,6 +27,6 @@ void MDFNMP_RemoveReadPatches(void);
 
 void MDFNMP_ApplyPeriodicCheats(void);
 
-extern MDFNSetting MDFNMP_Settings[];
+extern const MDFNSetting MDFNMP_Settings[];
 
 #endif
