@@ -21,10 +21,7 @@
 
 #include "nes.h"
 
-#include <string.h>
-#include <string>
 #include <zlib.h>
-#include <math.h>
 
 #include "x6502.h"
 #include "cart.h"
@@ -53,7 +50,7 @@ static int Mirroring;
 static uint32 ROM_size;
 static uint32 VROM_size;
 
-static void NewiNES_Init(int num);
+static void NewiNES_Init(int num) MDFN_COLD;
 
 static int MapperNo;
 
@@ -89,7 +86,7 @@ static void iNES_StateAction(StateMem *sm, const unsigned load, const bool data_
  if(iNESCart.StateAction)	// Call after loading/saving VS Uni and iNES sections.
   iNESCart.StateAction(sm, load, data_only);
 }
-static void iNESFree(void)
+static MDFN_COLD void iNESFree(void)
 {
 	if(ROM)
 	{
@@ -110,7 +107,7 @@ static void iNESFree(void)
 	}
 }
 
-static void iNES_Reset(void)
+static MDFN_COLD void iNES_Reset(void)
 {
         if(head.ROM_type & 4)
          memcpy(TrainerRAM, trainerpoo, 512);
@@ -119,7 +116,7 @@ static void iNES_Reset(void)
 	 iNESCart.Reset(&iNESCart);
 }
 
-static void iNES_Power(void)
+static MDFN_COLD void iNES_Power(void)
 {
 	if(!VROM_size)
 	 memset(VROM, 0xFF, CHRRAMSize);
@@ -142,7 +139,7 @@ static void iNES_SaveNV(void)
 	MDFN_SaveGameSave(&iNESCart);
 }
 
-static void iNES_Kill(void)
+static MDFN_COLD void iNES_Kill(void)
 {
 	if(iNESCart.Close) iNESCart.Close();
 
@@ -556,7 +553,7 @@ bool iNES_TestMagic(MDFNFILE *fp)
  return true;
 }
 
-void iNESLoad(Stream *fp, NESGameType *gt)
+MDFN_COLD void iNESLoad(Stream *fp, NESGameType *gt)
 {
   try
   {
@@ -771,6 +768,7 @@ static const BMAPPING bmap[] = {
 	{ 34, Mapper34_Init, 0},
 	{ 37, Mapper37_Init, 0},
 	{ 38, Mapper38_Init, 0},
+	{ 40, Mapper40_Init, 0},
         { 41, Mapper41_Init, 0},
 	{ 42, BioMiracleA_Init, 0},
         { 44, Mapper44_Init, 0},
@@ -846,6 +844,7 @@ static const BMAPPING bmap[] = {
 	{ 185, Mapper185_Init, 0},
         { 187, Mapper187_Init, 0},
 	{ 189, Mapper189_Init, 0},
+	{ 190, Mapper190_Init, 0 },
 	{ 193, Mapper193_Init, 0},
 	{ 206, Mapper206_Init, 0},
 	{ 207, Mapper207_Init, 0},
