@@ -19,7 +19,6 @@
  */
 
 #include	"nes.h"
-#include        <stdarg.h>
 
 #include	"x6502.h"
 #include	"ppu/ppu.h"
@@ -143,7 +142,7 @@ static DECLFW(BOverflow)
 	return(BWrite[A](A, V));
 }
 
-static void Cleanup(void)
+static MDFN_COLD void Cleanup(void)
 {
  for(std::vector<EXPSOUND>::iterator ep = GameExpSound.begin(); ep != GameExpSound.end(); ep++)
  {
@@ -163,7 +162,7 @@ static void Cleanup(void)
  MDFNPPU_Close();
 }
 
-static void CloseGame(void)
+static MDFN_COLD void CloseGame(void)
 {
  if(GameInterface.SaveNV)
   GameInterface.SaveNV();
@@ -171,9 +170,9 @@ static void CloseGame(void)
  Cleanup();
 }
 
-static void InitCommon(const std::string& fbase)
+static MDFN_COLD void InitCommon(const std::string& fbase)
 {
-        NESIsVSUni = FALSE;
+        NESIsVSUni = false;
         PPU_hook = 0;
         GameHBIRQHook = 0;
 
@@ -184,7 +183,7 @@ static void InitCommon(const std::string& fbase)
         MDFNGameInfo->VideoSystem = VIDSYS_NONE;
 
         MDFNGameInfo->cspecial = NULL;
-        MDFNGameInfo->GameSetMD5Valid = FALSE;
+        MDFNGameInfo->GameSetMD5Valid = false;
 
 
         if(MDFN_GetSettingB("nes.fnscan"))
@@ -193,8 +192,8 @@ static void InitCommon(const std::string& fbase)
           MDFNGameInfo->VideoSystem = VIDSYS_NTSC;
          else if(fbase.find("(J)") != std::string::npos || fbase.find("(Japan)") != std::string::npos)
           MDFNGameInfo->VideoSystem = VIDSYS_NTSC;
-         else if(fbase.find("(E)") != std::string::npos || fbase.find("(G)") != std::string::npos ||
-	         fbase.find("(Europe)") != std::string::npos || fbase.find("(Germany)") != std::string::npos)
+         else if(fbase.find("(E)") != std::string::npos || fbase.find("(G)") != std::string::npos || fbase.find("(F)") != std::string::npos ||
+	         fbase.find("(Europe)") != std::string::npos || fbase.find("(Germany)") != std::string::npos || fbase.find("(France)") != std::string::npos)
           MDFNGameInfo->VideoSystem = VIDSYS_PAL;
         }
 
@@ -224,9 +223,9 @@ static void InitCommon(const std::string& fbase)
         #endif
 }
 
-void UNIFLoad(Stream *fp, NESGameType *);
-void iNESLoad(Stream *fp, NESGameType *);
-void FDSLoad(Stream *fp, NESGameType *);
+void UNIFLoad(Stream *fp, NESGameType *) MDFN_COLD;
+void iNESLoad(Stream *fp, NESGameType *) MDFN_COLD;
+void FDSLoad(Stream *fp, NESGameType *) MDFN_COLD;
 
 bool iNES_TestMagic(MDFNFILE *fp);
 bool UNIF_TestMagic(MDFNFILE *fp);
@@ -258,7 +257,7 @@ static bool TestMagic(MDFNFILE *fp)
  return(GetLoadFunctionByMagic(fp) != NULL);
 }
 
-static void Load(MDFNFILE *fp)
+static MDFN_COLD void Load(MDFNFILE *fp)
 {
  try
  {
@@ -466,7 +465,7 @@ static const MDFNSetting_EnumList NTSCPresetList[] =
  { NULL, 0 },
 };
 
-static MDFNSetting NESSettings[] =
+static const MDFNSetting NESSettings[] =
 {
   { "nes.nofs", MDFNSF_EMU_STATE | MDFNSF_UNTRUSTED_SAFE, gettext_noop("Disable four-score emulation."), NULL, MDFNST_BOOL, "0" },
 
@@ -803,7 +802,7 @@ MDFNGI EmulatedNES =
  NESSettings,
  0,
  0,
- FALSE,	// Multires
+ false,	// Multires
 
  0,   // lcm_width		(replaced in game load)
  0,   // lcm_height           	(replaced in game load)
