@@ -25,7 +25,6 @@
 
 #include "pce.h"
 #include "huc.h"
-#include <math.h>
 #include <mednafen/video.h>
 #include "vce.h"
 #include <mednafen/hw_video/huc6270/vdc.h>
@@ -38,7 +37,7 @@ namespace MDFN_IEN_PCE
 
 static const int vce_ratios[4] = { 4, 3, 2, 2 };
 
-static NO_INLINE int32 Sync(const int32 timestamp);
+static MDFN_FASTCALL NO_INLINE int32 Sync(const int32 timestamp);
 
 static void IRQChange_Hook(bool newstatus)
 {
@@ -70,7 +69,7 @@ bool VCE::WS_Hook(int32 vdc_cycles)
   if(to_steal < 0)
    to_steal = 0;
 
-  ret = FALSE;
+  ret = false;
  }
 
  if(to_steal > 0)
@@ -487,7 +486,7 @@ INLINE void VCE::SyncSub(int32 clocks)
 #endif
 
     pixel_offset = 0;
-    NeedSLReset = FALSE;
+    NeedSLReset = false;
 
     if(!skipframe)
     {
@@ -543,7 +542,7 @@ INLINE void VCE::SyncSub(int32 clocks)
 
    if(!vblank)
    {
-    NeedSLReset = TRUE;
+    NeedSLReset = true;
    }
 
    child_event[0] = vdc[0].VSync(vblank);
@@ -578,7 +577,7 @@ INLINE int32 VCE::SyncReal(const int32 timestamp)
  return(ret);
 }
 
-static NO_INLINE int32 Sync(const int32 timestamp)
+static MDFN_FASTCALL NO_INLINE int32 Sync(const int32 timestamp)
 {
  extern VCE *vce; //HORRIBLE
  return vce->SyncReal(timestamp);
