@@ -29,7 +29,7 @@ namespace MDFN_IEN_PSX
 
 extern DebuggerInfoStruct PSX_DBGInfo;
 
-bool DBG_Init(void);
+bool DBG_Init(void) MDFN_COLD;
 
 void DBG_Break(void);
 
