@@ -2,7 +2,7 @@
 /* Mednafen Sony PS1 Emulation Module                                         */
 /******************************************************************************/
 /* frontio.cpp:
-**  Copyright (C) 2011-2016 Mednafen Team
+**  Copyright (C) 2011-2017 Mednafen Team
 **
 ** This program is free software; you can redistribute it and/or
 ** modify it under the terms of the GNU General Public License
@@ -144,6 +144,10 @@ void InputDevice::UpdateInput(const void *data)
 {
 }
 
+void InputDevice::UpdateOutput(void* data)
+{
+}
+
 void InputDevice::TransformInput(void* data)
 {
 }
@@ -766,6 +770,12 @@ void FrontIO::UpdateInput(void)
   Devices[i]->UpdateInput(DeviceData[i]);
 }
 
+void FrontIO::UpdateOutput(void)
+{
+ for(unsigned i = 0; i < 8; i++)
+  Devices[i]->UpdateOutput(DeviceData[i]);
+}
+
 // Take care to call ->Power() only if the device actually changed.
 void FrontIO::SetInput(unsigned int port, const char *type, uint8 *ptr)
 {
