@@ -2,7 +2,7 @@
 /* Mednafen Sony PS1 Emulation Module                                         */
 /******************************************************************************/
 /* dualshock.cpp:
-**  Copyright (C) 2012-2016 Mednafen Team
+**  Copyright (C) 2012-2017 Mednafen Team
 **
 ** This program is free software; you can redistribute it and/or
 ** modify it under the terms of the GNU General Public License
@@ -60,15 +60,16 @@ class InputDevice_DualShock final : public InputDevice
 {
  public:
 
- InputDevice_DualShock();
- virtual ~InputDevice_DualShock() override;
+ InputDevice_DualShock() MDFN_COLD;
+ virtual ~InputDevice_DualShock() override MDFN_COLD;
 
- virtual void Power(void) override;
+ virtual void Power(void) override MDFN_COLD;
  virtual void StateAction(StateMem* sm, const unsigned load, const bool data_only, const char* sname_prefix) override;
 
  virtual void Update(const pscpu_timestamp_t timestamp) override;
  virtual void ResetTS(void) override;
  virtual void UpdateInput(const void *data) override;
+ virtual void UpdateOutput(void* data) override;
  virtual void TransformInput(void* data) override;
 
  virtual void SetAMCT(bool enabled, uint16 compare) override;
@@ -288,7 +289,6 @@ void InputDevice_DualShock::StateAction(StateMem* sm, const unsigned load, const
 void InputDevice_DualShock::UpdateInput(const void *data)
 {
  uint8 *d8 = (uint8 *)data;
- uint8* const rumb_dp = &d8[3 + 16];
 
  buttons[0] = d8[0];
  buttons[1] = d8[1];
@@ -308,7 +308,17 @@ void InputDevice_DualShock::UpdateInput(const void *data)
   }
  }
 
- //printf("%3d:%3d, %3d:%3d\n", axes[0][0], axes[0][1], axes[1][0], axes[1][1]);
+ //printf("%d %d %d %d\n", axes[0][0], axes[0][1], axes[1][0], axes[1][1]);
+ //
+ //
+ //
+ CheckManualAnaModeChange();
+}
+
+void InputDevice_DualShock::UpdateOutput(void* data)
+{
+ uint8 *d8 = (uint8 *)data;
+ uint8* const rumb_dp = &d8[3 + 16];
 
  //printf("RUMBLE: 0x%02x 0x%02x 0x%02x 0x%02x 0x%02x 0x%02x\n", rumble_magic[0], rumble_magic[1], rumble_magic[2], rumble_magic[3], rumble_magic[4], rumble_magic[5]);
  //printf("%d, 0x%02x 0x%02x\n", da_rumble_compat, rumble_param[0], rumble_param[1]);
@@ -332,15 +342,8 @@ void InputDevice_DualShock::UpdateInput(const void *data)
   MDFN_en16lsb(rumb_dp, sneaky_weaky << 0);
  }
 
- //printf("%d %d %d %d\n", axes[0][0], axes[0][1], axes[1][0], axes[1][1]);
-
  //
- //
- //
- CheckManualAnaModeChange();
-
- //
- // Encode analog mode state last.
+ // Encode analog mode state.
  //
  d8[2] &= ~0x6;
  d8[2] |= (analog_mode ? 0x02 : 0x00);
@@ -1100,15 +1103,15 @@ const IDIISG Device_DualShock_IDII =
 
  IDIIS_Status("amstatus", "Analog Mode", AM_SS, sizeof(AM_SS) / sizeof(AM_SS[0])),
 
- { "rstick_right", "Right Stick RIGHT →", 22, IDIT_BUTTON_ANALOG, NULL, { NULL, NULL, NULL }, IDIT_BUTTON_ANALOG_FLAG_SQLR },
- { "rstick_left", "Right Stick LEFT ←", 21, IDIT_BUTTON_ANALOG, NULL, { NULL, NULL, NULL }, IDIT_BUTTON_ANALOG_FLAG_SQLR },
- { "rstick_down", "Right Stick DOWN ↓", 20, IDIT_BUTTON_ANALOG, NULL, { NULL, NULL, NULL }, IDIT_BUTTON_ANALOG_FLAG_SQLR },
- { "rstick_up", "Right Stick UP ↑", 19, IDIT_BUTTON_ANALOG, NULL, { NULL, NULL, NULL }, IDIT_BUTTON_ANALOG_FLAG_SQLR },
+ { "rstick_right", "Right Stick RIGHT →", 22, IDIT_BUTTON_ANALOG, NULL, IDIT_BUTTON_ANALOG_FLAG_SQLR },
+ { "rstick_left", "Right Stick LEFT ←", 21, IDIT_BUTTON_ANALOG, NULL, IDIT_BUTTON_ANALOG_FLAG_SQLR },
+ { "rstick_down", "Right Stick DOWN ↓", 20, IDIT_BUTTON_ANALOG, NULL, IDIT_BUTTON_ANALOG_FLAG_SQLR },
+ { "rstick_up", "Right Stick UP ↑", 19, IDIT_BUTTON_ANALOG, NULL, IDIT_BUTTON_ANALOG_FLAG_SQLR },
 
- { "lstick_right", "Left Stick RIGHT →", 17, IDIT_BUTTON_ANALOG, NULL, { NULL, NULL, NULL }, IDIT_BUTTON_ANALOG_FLAG_SQLR },
- { "lstick_left", "Left Stick LEFT ←", 16, IDIT_BUTTON_ANALOG, NULL, { NULL, NULL, NULL }, IDIT_BUTTON_ANALOG_FLAG_SQLR },
- { "lstick_down", "Left Stick DOWN ↓", 15, IDIT_BUTTON_ANALOG, NULL, { NULL, NULL, NULL }, IDIT_BUTTON_ANALOG_FLAG_SQLR },
- { "lstick_up", "Left Stick UP ↑", 14, IDIT_BUTTON_ANALOG, NULL, { NULL, NULL, NULL }, IDIT_BUTTON_ANALOG_FLAG_SQLR },
+ { "lstick_right", "Left Stick RIGHT →", 17, IDIT_BUTTON_ANALOG, NULL, IDIT_BUTTON_ANALOG_FLAG_SQLR },
+ { "lstick_left", "Left Stick LEFT ←", 16, IDIT_BUTTON_ANALOG, NULL, IDIT_BUTTON_ANALOG_FLAG_SQLR },
+ { "lstick_down", "Left Stick DOWN ↓", 15, IDIT_BUTTON_ANALOG, NULL, IDIT_BUTTON_ANALOG_FLAG_SQLR },
+ { "lstick_up", "Left Stick UP ↑", 14, IDIT_BUTTON_ANALOG, NULL, IDIT_BUTTON_ANALOG_FLAG_SQLR },
 
  { "rumble", "RUMBLE MONSTER RUMBA", 100, IDIT_RUMBLE },
 };
