@@ -24,7 +24,7 @@
 
 namespace MDFN_IEN_PSX
 {
- InputDevice *Device_neGcon_Create(void);
+ InputDevice *Device_neGcon_Create(void) MDFN_COLD;
  extern IDIISG Device_neGcon_IDII;
 }
 #endif
