@@ -2,7 +2,7 @@
 /* Mednafen Sony PS1 Emulation Module                                         */
 /******************************************************************************/
 /* psx.cpp:
-**  Copyright (C) 2011-2016 Mednafen Team
+**  Copyright (C) 2011-2017 Mednafen Team
 **
 ** This program is free software; you can redistribute it and/or
 ** modify it under the terms of the GNU General Public License
@@ -33,7 +33,6 @@
 #include <mednafen/hash/sha256.h>
 #include <mednafen/cheat_formats/psx.h>
 
-#include <stdarg.h>
 #include <ctype.h>
 
 #include <zlib.h>
@@ -84,7 +83,7 @@ static unsigned const psx_dbg_level = 0;
 
 struct MDFN_PseudoRNG	// Based off(but not the same as) public-domain "JKISS" PRNG.
 {
- MDFN_PseudoRNG()
+ MDFN_COLD MDFN_PseudoRNG()
  {
   ResetState();
  }
@@ -122,7 +121,7 @@ struct MDFN_PseudoRNG	// Based off(but not the same as) public-domain "JKISS" PR
   return(mina + tmp);
  }
 
- void ResetState(void)	// Must always reset to the same state.
+ MDFN_COLD void ResetState(void)	// Must always reset to the same state.
  {
   x = 123456789;
   y = 987654321;
@@ -147,10 +146,10 @@ class PSF1Loader : public PSFLoader
 {
  public:
 
- PSF1Loader(Stream *fp);
- virtual ~PSF1Loader() override;
+ PSF1Loader(Stream *fp) MDFN_COLD;
+ virtual ~PSF1Loader() override MDFN_COLD;
 
- virtual void HandleEXE(Stream* fp, bool ignore_pcsp = false) override;
+ virtual void HandleEXE(Stream* fp, bool ignore_pcsp = false) override MDFN_COLD;
 
  PSFTags tags;
 };
@@ -229,7 +228,6 @@ static int64 Memcard_SaveDelay[8];
 
 PS_CPU *CPU = NULL;
 PS_SPU *SPU = NULL;
-PS_GPU *GPU = NULL;
 PS_CDC *CDC = NULL;
 FrontIO *FIO = NULL;
 
@@ -389,7 +387,7 @@ void PSX_SetEventNT(const int type, const pscpu_timestamp_t next_timestamp)
 // Called from debug.cpp too.
 void ForceEventUpdates(const pscpu_timestamp_t timestamp)
 {
- PSX_SetEventNT(PSX_EVENT_GPU, GPU->Update(timestamp));
+ PSX_SetEventNT(PSX_EVENT_GPU, GPU_Update(timestamp));
  PSX_SetEventNT(PSX_EVENT_CDC, CDC->Update(timestamp));
 
  PSX_SetEventNT(PSX_EVENT_TIMER, TIMER_Update(timestamp));
@@ -415,7 +413,7 @@ bool MDFN_FASTCALL PSX_EventHandler(const pscpu_timestamp_t timestamp)
    default: abort();
 
    case PSX_EVENT_GPU:
-	nt = GPU->Update(e->event_time);
+	nt = GPU_Update(e->event_time);
 	break;
 
    case PSX_EVENT_CDC:
@@ -596,9 +594,9 @@ template<typename T, bool IsWrite, bool Access24> static INLINE void MemRW(pscpu
     timestamp++;
 
    if(IsWrite)
-    GPU->Write(timestamp, A, V);
+    GPU_Write(timestamp, A, V);
    else
-    V = GPU->Read(timestamp, A);
+    V = GPU_Read(timestamp, A);
 
    return;
   }
@@ -1050,7 +1048,7 @@ static void PSX_Reset(bool powering_up)
 
  MDEC_Power();
  CDC->Power();
- GPU->Power();
+ GPU_Power();
  //SPU->Power();	// Called from CDC->Power()
  IRQ_Power();
 
@@ -1087,7 +1085,7 @@ static void Emulate(EmulateSpecStruct *espec)
  espec->SoundBufSize = 0;
 
  FIO->UpdateInput();
- GPU->StartFrame(psf_loader ? NULL : espec);
+ GPU_StartFrame(psf_loader ? NULL : espec);
  SPU->StartFrame(espec->SoundRate, MDFN_GetSettingUI("psx.spu.resamp_quality"));
 
  Running = -1;
@@ -1096,10 +1094,10 @@ static void Emulate(EmulateSpecStruct *espec)
  assert(timestamp);
 
  ForceEventUpdates(timestamp);
- if(GPU->GetScanlineNum() < 100)
-  PSX_DBG(PSX_DBG_ERROR, "[BUUUUUUUG] Frame timing end glitch; scanline=%u, st=%u\n", GPU->GetScanlineNum(), timestamp);
+ if(GPU_GetScanlineNum() < 100)
+  PSX_DBG(PSX_DBG_ERROR, "[BUUUUUUUG] Frame timing end glitch; scanline=%u, st=%u\n", GPU_GetScanlineNum(), timestamp);
 
- //printf("scanline=%u, st=%u\n", GPU->GetScanlineNum(), timestamp);
+ //printf("scanline=%u, st=%u\n", GPU_GetScanlineNum(), timestamp);
 
  espec->SoundBufSize = SPU->EndFrame(espec->SoundBuf, espec->NeedSoundReverse);
  espec->NeedSoundReverse = false;
@@ -1107,7 +1105,7 @@ static void Emulate(EmulateSpecStruct *espec)
  CDC->ResetTS();
  TIMER_ResetTS();
  DMA_ResetTS();
- GPU->ResetTS();
+ GPU_ResetTS();
  FIO->ResetTS();
 
  RebaseTS(timestamp);
@@ -1123,6 +1121,8 @@ static void Emulate(EmulateSpecStruct *espec)
   }
  }
 
+ FIO->UpdateOutput();
+
  // Save memcards if dirty.
  for(int i = 0; i < 8; i++)
  {
@@ -1565,7 +1565,7 @@ static void DiscSanityChecks(void)
  }
 }
 
-static void InitCommon(std::vector<CDIF *> *CDInterfaces, const bool EmulateMemcards = true, const bool WantPIOMem = false)
+static MDFN_COLD void InitCommon(std::vector<CDIF *> *CDInterfaces, const bool EmulateMemcards = true, const bool WantPIOMem = false)
 {
  unsigned region;
  int sls, sle;
@@ -1607,7 +1607,7 @@ static void InitCommon(std::vector<CDIF *> *CDInterfaces, const bool EmulateMemc
 
  CPU = new PS_CPU();
  SPU = new PS_SPU();
- GPU = new PS_GPU(region == REGION_EU);
+ GPU_Init(region == REGION_EU);
  CDC = new PS_CDC();
  FIO = new FrontIO();
 
@@ -1645,7 +1645,7 @@ static void InitCommon(std::vector<CDIF *> *CDInterfaces, const bool EmulateMemc
 
  DMA_Init();
 
- GPU->SetGetVideoParams(&EmulatedPSX, sls, sle, MDFN_GetSettingB("psx.h_overscan"));
+ GPU_SetGetVideoParams(&EmulatedPSX, sls, sle, MDFN_GetSettingB("psx.h_overscan"));
 
  CDC->SetDisc(true, NULL, NULL);
 
@@ -1751,7 +1751,7 @@ static void InitCommon(std::vector<CDIF *> *CDInterfaces, const bool EmulateMemc
  PSX_Reset(true);
 }
 
-static void LoadEXE(Stream* fp, bool ignore_pcsp = false)
+static MDFN_COLD void LoadEXE(Stream* fp, bool ignore_pcsp = false)
 {
  uint8 raw_header[0x800];
  uint32 PC;
@@ -1946,7 +1946,7 @@ void PSF1Loader::HandleEXE(Stream* fp, bool ignore_pcsp)
 }
 
 static void Cleanup(void);
-static void Load(MDFNFILE *fp)
+static MDFN_COLD void Load(MDFNFILE *fp)
 {
  try
  {
@@ -1960,6 +1960,7 @@ static void Load(MDFNFILE *fp)
   if(MDFN_GetSettingS("psx.dbg_exe_cdpath") != "")	// For testing/debug purposes.
   {
    RMD_Drive dr;
+   RMD_DriveDefaults drdef;
 
    dr.Name = std::string("Virtual CD Drive");
    dr.PossibleStates.push_back(RMD_State({"Tray Open", false, false, true}));
@@ -1968,7 +1969,12 @@ static void Load(MDFNFILE *fp)
    dr.CompatibleMedia.push_back(0);
    dr.MediaMtoPDelay = 2000;
 
+   drdef.State = 2; // Tray Closed
+   drdef.Media = 0;
+   drdef.Orientation = 0;
+
    MDFNGameInfo->RMD->Drives.push_back(dr);
+   MDFNGameInfo->RMD->DrivesDefaults.push_back(drdef);
    MDFNGameInfo->RMD->MediaTypes.push_back(RMD_MediaType({"CD"}));
    MDFNGameInfo->RMD->Media.push_back(RMD_Media({"Test CD", 0}));
 
@@ -2002,7 +2008,7 @@ static void Load(MDFNFILE *fp)
  }
 }
 
-static void LoadCD(std::vector<CDIF *> *CDInterfaces)
+static MDFN_COLD void LoadCD(std::vector<CDIF *> *CDInterfaces)
 {
  try
  {
@@ -2015,7 +2021,7 @@ static void LoadCD(std::vector<CDIF *> *CDInterfaces)
  }
 }
 
-static void Cleanup(void)
+static MDFN_COLD void Cleanup(void)
 {
  TextMem.resize(0);
 
@@ -2037,11 +2043,7 @@ static void Cleanup(void)
   SPU = NULL;
  }
 
- if(GPU)
- {
-  delete GPU;
-  GPU = NULL;
- }
+ GPU_Kill();
 
  if(CPU)
  {
@@ -2072,7 +2074,7 @@ static void Cleanup(void)
  cdifs = NULL;
 }
 
-static void CloseGame(void)
+static MDFN_COLD void CloseGame(void)
 {
  if(!psf_loader)
  {
@@ -2153,7 +2155,7 @@ static void StateAction(StateMem *sm, const unsigned load, const bool data_only)
 
  CDC->StateAction(sm, load, data_only);
  MDEC_StateAction(sm, load, data_only);
- GPU->StateAction(sm, load, data_only);
+ GPU_StateAction(sm, load, data_only);
  SPU->StateAction(sm, load, data_only);
 
  FIO->StateAction(sm, load, data_only);
@@ -2216,7 +2218,7 @@ static const FileExtensionSpecStruct KnownExtensions[] =
  { NULL, NULL }
 };
 
-static MDFNSetting PSXSettings[] =
+static const MDFNSetting PSXSettings[] =
 {
  { "psx.input.mouse_sensitivity", MDFNSF_NOFLAGS, gettext_noop("Emulated mouse sensitivity."), NULL, MDFNST_FLOAT, "1.00", NULL, NULL },
 
