@@ -2,7 +2,7 @@
 /* Mednafen - Multi-system Emulator                                           */
 /******************************************************************************/
 /* settings.cpp:
-**  Copyright (C) 2005-2016 Mednafen Team
+**  Copyright (C) 2005-2017 Mednafen Team
 **
 ** This program is free software; you can redistribute it and/or
 ** modify it under the terms of the GNU General Public License
@@ -24,33 +24,29 @@
 */
 
 #include "mednafen.h"
-#include <errno.h>
-#include <string.h>
-#include <vector>
-#include <string>
 #include <trio/trio.h>
-#include <math.h>
 #include <locale.h>
 #include <map>
-#include <list>
 #include "settings.h"
 #include "string/escape.h"
-#include "string/trim.h"
+#include <mednafen/string/string.h>
 #include "FileStream.h"
 #include "MemoryStream.h"
 
 #include <zlib.h>
 
+static bool SettingsFinalized = false;
+
 typedef struct
 {
  char *name;
  char *value;
 } UnknownSetting_t;
 
-std::multimap <uint32, MDFNCS> CurrentSettings;
+std::vector<MDFNCS> CurrentSettings;
 std::vector<UnknownSetting_t> UnknownSettings;
 
-static MDFNCS *FindSetting(const char *name, bool deref_alias = true, bool dont_freak_out_on_fail = false);
+static MDFNCS *FindSetting(const char *name, bool dont_freak_out_on_fail = false);
 
 
 static bool TranslateSettingValueUI(const char *value, unsigned long long &tlated_value)
@@ -217,23 +213,21 @@ static void ValidateSetting(const char *value, const MDFNSetting *setting)
   {
    double minimum;
 
-   assert(MR_StringToDouble(setting->minimum, &minimum) == true);
+   if(MDFN_UNLIKELY(!MR_StringToDouble(setting->minimum, &minimum)))
+    throw MDFN_Error(0, _("Minimum value, \"%f\", for setting \"%s\" is not set to a floating-point(real) number."), minimum, setting->name);
 
-   if(dvalue < minimum)
-   {
+   if(MDFN_UNLIKELY(dvalue < minimum))
     throw MDFN_Error(0, _("Setting \"%s\" is set too small(\"%s\"); the minimum acceptable value is \"%s\"."), setting->name, value, setting->minimum);
-   }
   }
   if(setting->maximum)
   {
    double maximum;
 
-   assert(MR_StringToDouble(setting->maximum, &maximum) == true);
+   if(MDFN_UNLIKELY(!MR_StringToDouble(setting->maximum, &maximum)))
+    throw MDFN_Error(0, _("Maximum value, \"%f\", for setting \"%s\" is not set to a floating-point(real) number."), maximum, setting->name);
 
-   if(dvalue > maximum)
-   {
+   if(MDFN_UNLIKELY(dvalue > maximum))
     throw MDFN_Error(0, _("Setting \"%s\" is set too large(\"%s\"); the maximum acceptable value is \"%s\"."), setting->name, value, setting->maximum);
-   }
   }
  }
  else if(base_type == MDFNST_BOOL)
@@ -270,7 +264,45 @@ static void ValidateSetting(const char *value, const MDFNSetting *setting)
    throw MDFN_Error(0, _("Setting \"%s\", value \"%s\", is not a recognized string.  Recognized strings: %s"), setting->name, value, valid_string_list.c_str());
   }
  }
+ else if(base_type == MDFNST_MULTI_ENUM)
+ {
+  std::vector<std::string> mel = MDFN_strsplit(value);
 
+  assert(setting->enum_list);
+
+  for(auto& mee : mel)
+  {
+   bool found = false;
+   const MDFNSetting_EnumList* enum_list = setting->enum_list;
+
+   MDFN_trim(mee);
+
+   while(enum_list->string)
+   {
+    if(!strcasecmp(mee.c_str(), enum_list->string))
+    {
+     found = true;
+     break;
+    }
+    enum_list++;
+   }
+
+   if(!found)
+   {
+    std::string valid_string_list;
+
+    enum_list = setting->enum_list;
+    while(enum_list->string)
+    {
+     if(enum_list->description)	// Don't list out undocumented and deprecated values.
+      valid_string_list = valid_string_list + (enum_list == setting->enum_list ? "" : " ") + std::string(enum_list->string);
+
+     enum_list++;
+    }
+    throw MDFN_Error(0, _("Setting \"%s\", value \"%s\" component \"%s\", is not a recognized string.  Recognized strings: %s"), setting->name, value, mee.c_str(), valid_string_list.c_str());
+   }
+  }
+ }
 
  if(setting->validate_func && !setting->validate_func(setting->name, value))
  {
@@ -283,11 +315,7 @@ static void ValidateSetting(const char *value, const MDFNSetting *setting)
 
 static uint32 MakeNameHash(const char *name)
 {
- uint32 name_hash;
-
- name_hash = crc32(0, (const Bytef *)name, strlen(name));
-
- return(name_hash);
+ return crc32(0, (const Bytef *)name, strlen(name));
 }
 
 static void ParseSettingLine(std::string &linebuf, size_t* valid_count, size_t* unknown_count, bool IsOverrideSetting = false)
@@ -318,7 +346,7 @@ static void ParseSettingLine(std::string &linebuf, size_t* valid_count, size_t*
  else
   linebuf[spacepos] = 0;
 
- zesetting = FindSetting(linebuf.c_str(), true, true);
+ zesetting = FindSetting(linebuf.c_str(), true);
 
  if(zesetting)
  {
@@ -409,16 +437,16 @@ void MDFN_LoadSettings(const std::string& path, bool override)
  }
 }
 
-static bool compare_sname(MDFNCS *first, MDFNCS *second)
+static bool compare_sname(const MDFNCS* first, const MDFNCS* second)
 {
  return(strcmp(first->name, second->name) < 0);
 }
 
 static void SaveSettings(Stream *fp)
 {
- std::multimap <uint32, MDFNCS>::iterator sit;
- std::list<MDFNCS *> SortedList;
- std::list<MDFNCS *>::iterator lit;
+ std::vector<MDFNCS>::iterator sit;
+ std::list<MDFNCS*> SortedList;
+ std::list<MDFNCS*>::iterator lit;
 
  fp->print_format(";VERSION %s\n", MEDNAFEN_VERSION);
 
@@ -426,7 +454,7 @@ static void SaveSettings(Stream *fp)
  fp->print_format(_(";File format: <key><single space><value><LF or CR+LF>\n\n"));
 
  for(sit = CurrentSettings.begin(); sit != CurrentSettings.end(); sit++)
-  SortedList.push_back(&sit->second);
+  SortedList.push_back(&*sit);
 
  SortedList.sort(compare_sname);
 
@@ -435,6 +463,9 @@ static void SaveSettings(Stream *fp)
   if((*lit)->desc->type == MDFNST_ALIAS)
    continue;
 
+  if((*lit)->desc->flags & MDFNSF_NONPERSISTENT)
+   continue;
+
   fp->print_format(";%s\n%s %s\n\n", _((*lit)->desc->description), (*lit)->name, (*lit)->value);
  }
 
@@ -469,67 +500,94 @@ bool MDFN_SaveSettings(const std::string& path)
 
 static INLINE void MergeSettingSub(const MDFNSetting *setting)
 {
-  MDFNCS TempSetting;
-  uint32 name_hash;
+ MDFNCS TempSetting;
 
-  assert(setting->name);
-  assert(setting->default_value);
+ assert(setting->name);
+ assert(setting->default_value);
 
-  if(FindSetting(setting->name, false, true) != NULL)
-  {
-   printf("Duplicate setting name %s\n", setting->name);
-   abort();
-  }
+ TempSetting.name = strdup(setting->name);
+ TempSetting.value = strdup(setting->default_value);
+ TempSetting.name_hash = MakeNameHash(setting->name);
+ TempSetting.desc = setting;
+ TempSetting.ChangeNotification = setting->ChangeNotification;
+ TempSetting.game_override = NULL;
+ TempSetting.netplay_override = NULL;
 
-  name_hash = MakeNameHash(setting->name);
-
-  TempSetting.name = strdup(setting->name);
-  TempSetting.value = strdup(setting->default_value);
-  TempSetting.name_hash = name_hash;
-  TempSetting.desc = setting;
-  TempSetting.ChangeNotification = setting->ChangeNotification;
-  TempSetting.game_override = NULL;
-  TempSetting.netplay_override = NULL;
-
-  CurrentSettings.insert(std::pair<uint32, MDFNCS>(name_hash, TempSetting)); //[name_hash] = TempSetting;
+ CurrentSettings.push_back(TempSetting);
 }
 
-
-bool MDFN_MergeSettings(const MDFNSetting *setting)
+void MDFN_MergeSettings(const MDFNSetting *setting)
 {
  while(setting->name != NULL)
  {
   MergeSettingSub(setting);
   setting++;
  }
- return(1);
 }
 
-bool MDFN_MergeSettings(const std::vector<MDFNSetting> &setting)
+void MDFN_MergeSettings(const std::vector<MDFNSetting> &setting)
 {
+ assert(!SettingsFinalized);
+
  for(unsigned int x = 0; x < setting.size(); x++)
   MergeSettingSub(&setting[x]);
+}
 
- return(1);
+static bool CSHashSortFunc(const MDFNCS& a, const MDFNCS& b)
+{
+ return a.name_hash < b.name_hash;
+}
+
+static bool CSHashBoundFunc(const MDFNCS& a, const uint32 b)
+{
+ return a.name_hash < b;
+}
+
+void MDFN_FinalizeSettings(void)
+{
+ std::sort(CurrentSettings.begin(), CurrentSettings.end(), CSHashSortFunc);
+
+ //
+ // Ensure no duplicates.
+ //
+ for(size_t i = 0; i < CurrentSettings.size(); i++)
+ {
+  for(size_t j = i + 1; j < CurrentSettings.size() && CurrentSettings[j].name_hash == CurrentSettings[i].name_hash; j++)
+  {
+   if(!strcmp(CurrentSettings[i].name, CurrentSettings[j].name))
+   {
+    printf("Duplicate setting name %s\n", CurrentSettings[j].name);
+    abort();
+   }
+  }
+ }
+
+ SettingsFinalized = true;
+/*
+ for(size_t i = 0; i < CurrentSettings.size(); i++)
+ {
+  assert(CurrentSettings[i].desc->type == MDFNST_ALIAS || !strcmp(FindSetting(CurrentSettings[i].name)->name, CurrentSettings[i].name));
+ }
+*/
 }
 
 void MDFN_ClearAllOverrideSettings(void)
 {
  for(auto& sit : CurrentSettings)
  {
-  if(sit.second.desc->type == MDFNST_ALIAS)
+  if(sit.desc->type == MDFNST_ALIAS)
    continue;
 
-  if(sit.second.game_override)
+  if(sit.game_override)
   {
-   free(sit.second.game_override);
-   sit.second.game_override = NULL;
+   free(sit.game_override);
+   sit.game_override = NULL;
   }
 
-  if(sit.second.netplay_override)
+  if(sit.netplay_override)
   {
-   free(sit.second.netplay_override);
-   sit.second.netplay_override = NULL;
+   free(sit.netplay_override);
+   sit.netplay_override = NULL;
   }
  }
 }
@@ -538,17 +596,17 @@ void MDFN_KillSettings(void)
 {
  for(auto& sit : CurrentSettings)
  {
-  if(sit.second.desc->type == MDFNST_ALIAS)
+  if(sit.desc->type == MDFNST_ALIAS)
    continue;
 
-  free(sit.second.name);
-  free(sit.second.value);
+  free(sit.name);
+  free(sit.value);
 
-  if(sit.second.game_override)
-   free(sit.second.game_override);
+  if(sit.game_override)
+   free(sit.game_override);
 
-  if(sit.second.netplay_override)
-   free(sit.second.netplay_override);
+  if(sit.netplay_override)
+   free(sit.netplay_override);
  }
 
  if(UnknownSettings.size())
@@ -561,40 +619,38 @@ void MDFN_KillSettings(void)
  }
  CurrentSettings.clear();	// Call after the list is all handled
  UnknownSettings.clear();
+ SettingsFinalized = false;
 }
 
-static MDFNCS *FindSetting(const char *name, bool dref_alias, bool dont_freak_out_on_fail)
+static MDFNCS* FindSetting(const char* name, bool dont_freak_out_on_fail)
 {
- MDFNCS *ret = NULL;
- uint32 name_hash;
-
+ assert(SettingsFinalized);
  //printf("Find: %s\n", name);
+ const uint32 name_hash = MakeNameHash(name);
+ std::vector<MDFNCS>::iterator it;
 
- name_hash = MakeNameHash(name);
+ it = std::lower_bound(CurrentSettings.begin(), CurrentSettings.end(), name_hash, CSHashBoundFunc);
 
- std::pair<std::multimap <uint32, MDFNCS>::iterator, std::multimap <uint32, MDFNCS>::iterator> sit_pair;
- std::multimap <uint32, MDFNCS>::iterator sit;
-
- sit_pair = CurrentSettings.equal_range(name_hash);
-
- for(sit = sit_pair.first; sit != sit_pair.second; sit++)
+ while(it != CurrentSettings.end() && it->name_hash == name_hash)
  {
-  //printf("Found: %s\n", sit->second.name);
-  if(!strcmp(sit->second.name, name))
+  if(!strcmp(it->name, name))
   {
-   if(dref_alias && sit->second.desc->type == MDFNST_ALIAS)
-    return(FindSetting(sit->second.value, dref_alias, dont_freak_out_on_fail));
+   if(it->desc->type == MDFNST_ALIAS)
+    return FindSetting(it->value, dont_freak_out_on_fail);
 
-   ret = &sit->second;
+   return &*it;
   }
+  //printf("OHNOS: %s(%08x) %s(%08x)\n", name, name_hash, it->name, it->name_hash);
+  it++;
  }
 
- if(!ret && !dont_freak_out_on_fail)
+ if(!dont_freak_out_on_fail)
  {
   printf("\n\nINCONCEIVABLE!  Setting not found: %s\n\n", name);
   exit(1);
  }
- return(ret);
+
+ return NULL;
 }
 
 static const char *GetSetting(const MDFNCS *setting)
@@ -634,6 +690,38 @@ static int GetEnum(const MDFNCS *setting, const char *value)
  return(ret);
 }
 
+template<typename T>
+static std::vector<T> GetMultiEnum(const MDFNCS* setting, const char* value)
+{
+ std::vector<T> ret;
+ std::vector<std::string> mel = MDFN_strsplit(value);
+
+ assert(setting->desc->enum_list);
+
+ for(auto& mee : mel)
+ {
+  const MDFNSetting_EnumList *enum_list = setting->desc->enum_list;
+  bool found = false;
+
+  MDFN_trim(mee);
+
+  while(enum_list->string)
+  {
+   if(!strcasecmp(mee.c_str(), enum_list->string))
+   {
+    found = true;
+    ret.push_back(enum_list->number);
+    break;
+   }
+   enum_list++;
+  }
+  assert(found);
+ }
+
+ return ret;
+}
+
+
 uint64 MDFN_GetSettingUI(const char *name)
 {
  const MDFNCS *setting = FindSetting(name);
@@ -665,6 +753,29 @@ int64 MDFN_GetSettingI(const char *name)
  }
 }
 
+std::vector<uint64> MDFN_GetSettingMultiUI(const char *name)
+{
+ const MDFNCS *setting = FindSetting(name);
+ const char *value = GetSetting(setting);
+
+ if(setting->desc->type == MDFNST_MULTI_ENUM)
+  return GetMultiEnum<uint64>(setting, value);
+ else
+  abort();
+}
+
+std::vector<int64> MDFN_GetSettingMultiI(const char *name)
+{
+ const MDFNCS *setting = FindSetting(name);
+ const char *value = GetSetting(setting);
+
+ if(setting->desc->type == MDFNST_MULTI_ENUM)
+  return GetMultiEnum<int64>(setting, value);
+ else
+  abort();
+}
+
+
 double MDFN_GetSettingF(const char *name)
 {
  double ret;
@@ -693,14 +804,14 @@ std::string MDFN_GetSettingS(const char *name)
  return(std::string(value));
 }
 
-const std::multimap <uint32, MDFNCS> *MDFNI_GetSettings(void)
+const std::vector<MDFNCS>* MDFNI_GetSettings(void)
 {
- return(&CurrentSettings);
+ return &CurrentSettings;
 }
 
 bool MDFNI_SetSetting(const char *name, const char *value, bool NetplayOverride)
 {
- MDFNCS *zesetting = FindSetting(name, true, true);
+ MDFNCS *zesetting = FindSetting(name, true);
 
  if(zesetting)
  {
@@ -787,10 +898,8 @@ bool MDFNI_SetSettingUI(const char *name, uint64 value)
 void MDFNI_DumpSettingsDef(const char *path)
 {
  FileStream fp(path, FileStream::MODE_WRITE);
-
- std::multimap <uint32, MDFNCS>::iterator sit;
- std::list<MDFNCS *> SortedList;
- std::list<MDFNCS *>::iterator lit;
+ std::list<const MDFNCS *> SortedList;
+ std::list<const MDFNCS *>::iterator lit;
  std::map<int, const char *> tts;
  std::map<uint32, const char *>fts;
 
@@ -804,19 +913,21 @@ void MDFNI_DumpSettingsDef(const char *path)
  fts[MDFNSF_CAT_INPUT] = "MDFNSF_CAT_INPUT";
  fts[MDFNSF_CAT_SOUND] = "MDFNSF_CAT_SOUND";
  fts[MDFNSF_CAT_VIDEO] = "MDFNSF_CAT_VIDEO";
+ fts[MDFNSF_CAT_INPUT_MAPPING] = "MDFNSF_CAT_INPUT_MAPPING";
 
  fts[MDFNSF_EMU_STATE] = "MDFNSF_EMU_STATE";
  fts[MDFNSF_UNTRUSTED_SAFE] = "MDFNSF_UNTRUSTED_SAFE";
 
  fts[MDFNSF_SUPPRESS_DOC] = "MDFNSF_SUPPRESS_DOC";
  fts[MDFNSF_COMMON_TEMPLATE] = "MDFNSF_COMMON_TEMPLATE";
+ fts[MDFNSF_NONPERSISTENT] = "MDFNSF_NONPERSISTENT";
 
  fts[MDFNSF_REQUIRES_RELOAD] = "MDFNSF_REQUIRES_RELOAD";
  fts[MDFNSF_REQUIRES_RESTART] = "MDFNSF_REQUIRES_RESTART";
 
 
- for(sit = CurrentSettings.begin(); sit != CurrentSettings.end(); sit++)
-  SortedList.push_back(&sit->second);
+ for(const auto& sit : CurrentSettings)
+  SortedList.push_back(&sit);
 
  SortedList.sort(compare_sname);
 
@@ -833,8 +944,8 @@ void MDFNI_DumpSettingsDef(const char *path)
 
   for(unsigned int i = 0; i < 32; i++)
   {
-   if(setting->flags & (1 << i))
-    fp.print_format("%s ", fts[1 << i]);
+   if(setting->flags & (1U << i))
+    fp.print_format("%s ", fts[1U << i]);
   }
   fp.print_format("\n");
 
