@@ -597,7 +597,7 @@ void SMS_VDPRunFrame(int skip_render)
     }
 }
 
-int SMS_VDPStateAction(StateMem *sm, int load, int data_only)
+void SMS_VDPStateAction(StateMem *sm, int load, int data_only)
 {
  SFORMAT StateRegs[] =
  {
@@ -623,7 +623,7 @@ int SMS_VDPStateAction(StateMem *sm, int load, int data_only)
   SFEND
  };
 
- int ret = MDFNSS_StateAction(sm, load, data_only, StateRegs, "VDP");
+ MDFNSS_StateAction(sm, load, data_only, StateRegs, "VDP");
 
  if(load)
  {
@@ -650,8 +650,6 @@ int SMS_VDPStateAction(StateMem *sm, int load, int data_only)
   for(int i = 0; i < PALETTE_SIZE; i++)
    palette_sync(i, 1);
  }
-
- return(ret);
 }
 
 
