@@ -27,12 +27,12 @@
 namespace MDFN_IEN_SNES_FAUST
 {
 
-void APU_Init(void);
-void APU_Kill(void);
-void APU_Reset(bool powering_up);
+void APU_Init(const bool IsPAL) MDFN_COLD;
+void APU_Kill(void) MDFN_COLD;
+void APU_Reset(bool powering_up) MDFN_COLD;
 int32 APU_EndFrame(int16* SoundBuf);
-void APU_StartFrame(double rate);
-void APU_SetSPC(SPCReader* s);	// Call after APU_Reset()
+void APU_StartFrame(double master_clock, double rate);
+void APU_SetSPC(SPCReader* s) MDFN_COLD;	// Call after APU_Reset()
 
 void APU_StateAction(StateMem* sm, const unsigned load, const bool data_only);
 
