@@ -2,7 +2,7 @@
 /* Mednafen Sega Saturn Emulation Module                                      */
 /******************************************************************************/
 /* sh7095.h:
-**  Copyright (C) 2015-2016 Mednafen Team
+**  Copyright (C) 2015-2017 Mednafen Team
 **
 ** This program is free software; you can redistribute it and/or
 ** modify it under the terms of the GNU General Public License
@@ -29,7 +29,9 @@ class SH7095 final
  SH7095(const char* const name_arg, const unsigned dma_event_id_arg, uint8 (*exivecfn_arg)(void)) MDFN_COLD;
  ~SH7095() MDFN_COLD;
 
- void Init(void) MDFN_COLD;
+ void Init(const bool CacheBypassHack) MDFN_COLD;
+
+ void StateAction(StateMem* sm, const unsigned load, const bool data_only, const char* sname) MDFN_COLD;
 
  void ForceInternalEventUpdates(void);
  void AdjustTS(int32 delta, bool force_set = false);
@@ -51,7 +53,7 @@ class SH7095 final
    SetPEX(PEX_PSEUDO_EXTHALT);	// Only SetPEX() here, ClearPEX() is called in the pseudo exception handling code as necessary.
  }
 
- template<unsigned which, bool DebugMode>
+ template<unsigned which, bool EmulateICache, bool DebugMode>
  void Step(void);
 
 
@@ -244,7 +246,18 @@ class SH7095 final
  //
  //
  //
- uint16 BCR1, BCR1M;
+ struct
+ {
+  uint16 BCR1;
+  uint8 BCR2;
+  uint16 WCR;
+  uint16 MCR;
+
+  uint8 RTCSR;
+  uint8 RTCSRM;
+  uint8 RTCNT;
+  uint8 RTCOR;
+ } BSC;
 
  //
  //
@@ -312,6 +325,9 @@ class SH7095 final
  sscpu_timestamp_t DMA_Update(sscpu_timestamp_t);	// Takes/return external timestamp
  void DMA_StartSG(void);
 
+ void DMA_RecalcRunning(void);
+ void DMA_BusTimingKludge(void);
+
  const unsigned event_id_dma;
  sscpu_timestamp_t dma_lastts;	// External SH7095_mem_timestamp related.
 
@@ -319,6 +335,9 @@ class SH7095 final
  int32 DMA_SGCounter;	// When negative, smaller granularity scheduling for DMA_Update()
  bool DMA_RoundRobinRockinBoppin;
 
+ uint32 DMA_PenaltyKludgeAmount;
+ uint32 DMA_PenaltyKludgeAccum;
+
  struct
  {
   uint32 SAR;
@@ -378,10 +397,10 @@ class SH7095 final
  uint8 GetPendingInt(uint8*);
  void RecalcPendingIntPEX(void);
 
- template<bool DebugMode>
+ template<bool EmulateICache, bool DebugMode>
  INLINE void FetchIF(bool ForceIBufferFill);
 
- template<bool DebugMode, bool DelaySlot, bool IntPreventNext, bool SkipFetchIF>
+ template<bool EmulateICache, bool DebugMode, bool DelaySlot, bool IntPreventNext, bool SkipFetchIF>
  void DoIDIF_Real(void);
 
  template<typename T, bool BurstHax>
@@ -396,7 +415,7 @@ class SH7095 final
  template<typename T>
  T OnChipRegRead(uint32 A);
 
- template<typename T, unsigned region, bool CacheEnabled, bool TwoWayMode, bool IsInstr>
+ template<typename T, unsigned region, bool CacheEnabled, bool TwoWayMode, bool IsInstr, bool CacheBypassHack>
  T MemReadRT(uint32 A);
 
  template<typename T>
@@ -409,17 +428,17 @@ class SH7095 final
  void MemWrite(uint32 A, T V);
 
 
- template<unsigned which, int DebugMode, bool delayed>
+ template<unsigned which, bool EmulateICache, int DebugMode, bool delayed>
  INLINE void Branch(uint32 target);
 
- template<unsigned which, int DebugMode, bool delayed>
+ template<unsigned which, bool EmulateICache, int DebugMode, bool delayed>
  INLINE void CondRelBranch(bool cond, uint32 disp);
 
 
- template<unsigned which, int DebugMode>
+ template<unsigned which, bool EmulateICache, int DebugMode>
  INLINE void UCDelayBranch(uint32 target);
 
- template<unsigned which, int DebugMode>
+ template<unsigned which, bool EmulateICache, int DebugMode>
  INLINE void UCRelDelayBranch(uint32 disp);
 
 
@@ -528,6 +547,7 @@ class SH7095 final
  void CheckRWBreakpoints(void (*MRead)(unsigned len, uint32 addr), void (*MWrite)(unsigned len, uint32 addr)) const;
  static void Disassemble(const uint16 instr, const uint32 PC, char* buffer, uint16 (*DisPeek16)(uint32), uint32 (*DisPeek32)(uint32));
  private:
+ bool CBH_Setting;
  uint32 PC_IF, PC_ID;	// Debug-related variables.
 };
 
