@@ -2,7 +2,7 @@
 /* Mednafen Sega Saturn Emulation Module                                      */
 /******************************************************************************/
 /* ssf.cpp - SSF Playback Sub-Module
-**  Copyright (C) 2015-2016 Mednafen Team
+**  Copyright (C) 2015-2017 Mednafen Team
 **
 ** This program is free software; you can redistribute it and/or
 ** modify it under the terms of the GNU General Public License
@@ -147,7 +147,7 @@ static const FileExtensionSpecStruct KnownExtensions[] =
 };
 
 
-static MDFNSetting SSFPlaySettings[] =
+static const MDFNSetting SSFPlaySettings[] =
 {
  { "ssfplay.resamp_quality", MDFNSF_NOFLAGS, gettext_noop("SCSP output resampler quality."),
 	gettext_noop("0 is lowest quality and CPU usage, 10 is highest quality and CPU usage.  The resampler that this setting refers to is used for converting from 44.1KHz to the sampling rate of the host audio device Mednafen is using.  Changing Mednafen's output rate, via the \"sound.rate\" setting, to \"44100\" may bypass the resampler, which can decrease CPU usage by Mednafen, and can increase or decrease audio quality, depending on various operating system and hardware factors."), MDFNST_UINT, "4", "0", "10" },
@@ -187,7 +187,7 @@ MDFNGI EmulatedSSFPlay =
  CheatInfo_Empty,
 
  false,
- NULL, //StateAction,
+ SOUND_StateAction,
  Emulate,
  NULL,
  NULL,
